@@ -7,7 +7,8 @@
 package XML::Edifact;
 
 use 5.006;
-no warnings 'utf8' ;
+no warnings 'utf8';
+use bytes;
 
 use strict;
 use XML::Edifact::Config;
@@ -18,7 +19,7 @@ use Carp;
 
 use vars qw($VERSION $debug);
 
-$VERSION='0.45';
+$VERSION='0.47';
 $debug=1;					# debug=1 is fine
 
 # ------------------------------------------------------------------------------
@@ -63,6 +64,7 @@ use vars qw($advice_element_seperator $advice_decimal_notation);
 use vars qw($advice_release_indicator $advice_segment_terminator);
 use vars qw($indent_join $indent_tab);
 use vars qw($patch_segment $patch_composite $last_segment $last_composite);
+use vars qw($coded_entry);
 
 # ------------------------------------------------------------------------------
 
@@ -135,7 +137,7 @@ use vars qw($cooked_message_substitute $cooked_segment_substitute);
 use vars qw($component_split $element_split);
 
 sub make_xml_message {
-	my ($iofile,$handler) = @_;
+	my ($iofile) = @_;
 
 	@xml_msg = ();
 	push @xml_msg, $MESSAGE_HEADER;
@@ -391,7 +393,7 @@ sub read_xml_message {
 }
 
 sub make_edi_message {
-	my ($iofile,$handler) = @_;
+	my ($iofile) = @_;
 
         $edi_file = $iofile;
 
@@ -437,6 +439,8 @@ sub handle_start {
 		}
 	}
 
+	$coded_entry = 0;
+
 	if ($edi_level == 0) {
 		die "this is not XML::Edifact" if ($element !~ /^[^:]*:message/);
 		$edi_valid   = 1;
@@ -507,6 +511,7 @@ sub handle_start {
 					$val = $options{$opt};
 					$val =~ s/^[^:]*://;
 					$edi_group[$edi_gi] = $val;
+					$coded_entry = 1;
 				}
 			}
 		}
@@ -546,6 +551,7 @@ sub handle_start {
 					$val = $options{$opt};
 					$val =~ s/^[^:]*://;
 					$edi_group[$edi_gi] = $val;
+					$coded_entry = 1;
 				}
 			}
 		}
@@ -579,6 +585,8 @@ sub handle_end {
 	    if ($edi_level == 2) {
 		for ($i = 0; $i<= $#edi_group; $i++) {
 			$cooked = $edi_group[$i];
+			$cooked =~ s/^[\n\r\t ]*//;
+			$cooked =~ s/[\n\r\t ]*$//;
 
 			foreach $si ($advice_release_indicator, $advice_component_seperator, $advice_element_seperator, $advice_segment_terminator) {
 				$s1 = "\\".$si;
@@ -605,10 +613,8 @@ sub handle_char {
 		}
 
 		$element =~ s/([\xC0-\xDF])([\x80-\xBF])/chr(ord($1)<<6&0xC0|ord($2)&0x3F)/eg;
-		$element =~ s/[\n\r\t ]*$//;
-		$element =~ s/^[\n\r\t ]*//;
 
-		$edi_group[$edi_gi] = $element if $edi_group[$edi_gi] eq "";
+		$edi_group[$edi_gi] .= $element unless ($coded_entry);
 	}
 }
 
